WasmComponentExtension class final

A protocol extension allowing build hooks in packages to declare dependencies on WebAssembly components and to export Dart methods.

Constructors

WasmComponentExtension()

Properties

hashCode → int
The hash code for this object.
no setterinherited
logger → Logger
The logger of the hooks_runner that drives this extension.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outputFiles(List<EncodedAsset> assets) → Iterable<Uri>
Returns any files emitted by the hook output for this extension.
inherited
setupBuildInput(BuildInputBuilder input) → void
Setup the BuildConfig for this extension.
setupLinkInput(LinkInputBuilder input) → void
Setup the HookConfig for this extension.
inherited
setupLogger(Logger logger) → void
Sets up the logger used by the hooks_runner that drives this extension.
inherited
toString() → String
A string representation of this object.
inherited
validateApplicationAssets(List<EncodedAsset> assets) → Future<ValidationErrors>
Reports errors on the complete set of assets after all hooks are run.
inherited
validateBuildInput(BuildInput input) → Future<ValidationErrors>
Reports errors from this extension on the BuildInput.
inherited
validateBuildOutput(BuildInput input, BuildOutput output) → Future<ValidationErrors>
Reports errors from this extension on the LinkInput.
inherited
validateLinkInput(LinkInput input) → Future<ValidationErrors>
Reports errors from this extension on the LinkInput.
inherited
validateLinkOutput(LinkInput input, LinkOutput output) → Future<ValidationErrors>
Reports errors from this extension on the LinkOutput.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited