outputFiles method

Iterable<Uri> outputFiles(
  1. List<EncodedAsset> assets
)
inherited

Returns any files emitted by the hook output for this extension.

If any of these output files are modified or deleted, the hook needs to be rerun.

Implementation

Iterable<Uri> outputFiles(List<EncodedAsset> assets) => [];