setupLogger method

void setupLogger(
  1. Logger logger
)
inherited

Sets up the logger used by the hooks_runner that drives this extension.

Guaranteed to be run before any other method is called on this object.

The field backing logger is not final because the same extension object can be reused across the build and link of a single run.

Implementation

void setupLogger(Logger logger) {
  _logger = logger;
}