validateApplicationAssets method

Future<ValidationErrors> validateApplicationAssets(
  1. List<EncodedAsset> assets
)
inherited

Reports errors on the complete set of assets after all hooks are run.

Can be used to validate that there are no asset-id or shared library name collisions.

Implementation

Future<ValidationErrors> validateApplicationAssets(
  List<EncodedAsset> assets,
) async => [];