WasmComponentAsset class
final
Properties
-
encoded
→ Map<String, Object?>
-
The WIT context, as serialized by
wasm-tools component wit -j.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode()
→ EncodedAsset
-
Encodes this into an
EncodedAsset that can be added to
BuildOutputAssetsBuilder.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited