outputFiles method
Returns any files emitted by the hook output for this extension.
If any of these output files are modified or deleted, the hook needs to be rerun.
Implementation
Iterable<Uri> outputFiles(List<EncodedAsset> assets) => [];
Returns any files emitted by the hook output for this extension.
If any of these output files are modified or deleted, the hook needs to be rerun.
Iterable<Uri> outputFiles(List<EncodedAsset> assets) => [];